xitdb.common


IMaterializecljprotocol

-materializeclj

(-materialize this)
source

IMaterializeShallowcljprotocol

-materialize-shallowclj

(-materialize-shallow this)
source

IReadFromCursorcljprotocol

-read-from-cursorclj

(-read-from-cursor this)
source

IReadOnlycljprotocol

-read-onlyclj

(-read-only this)
source

ISlotcljprotocol

-slotclj

(-slot this)
source

IUnwrapcljprotocol

-unwrapclj

(-unwrap this)
source

materializeclj

(materialize v)
source

unwrapclj

(unwrap v)

For a value that wraps another value, returns the wrapped value.

For a value that wraps another value, returns the wrapped value.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries