(unwrap v)For a value that wraps another value, returns the wrapped value.
For a value that wraps another value, returns the wrapped value.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |