(array-list-write-cursor wal i)Returns a cursor to slot i in the array list. Throws if index is out of bounds.
Returns a cursor to slot i in the array list. Throws if index is out of bounds.
(coll->ArrayListCursor! cursor coll)Converts a Clojure collection to a XitDB ArrayList cursor. Handles nested maps and collections recursively. Returns the cursor of the created WriteArrayList.
Converts a Clojure collection to a XitDB ArrayList cursor. Handles nested maps and collections recursively. Returns the cursor of the created WriteArrayList.
(db-key-hash jdb v)Returns a byte array representing the stable hash digest of (Clojure) value v.
Uses the MessageDigest from the database.
Returns a byte array representing the stable hash digest of (Clojure) value `v`. Uses the MessageDigest from the database.
(default-sorted-comparator? coll)True if coll (a PersistentTreeMap or PersistentTreeSet) is ordered in a way
the engine can honour with its fixed unsigned byte ordering: either Clojure's
natural ordering (no custom comparator) or sorted-key/key-comparator, which
is that byte ordering and is what materialize stamps onto the collections
it rebuilds. Any other custom comparator is rejected.
True if `coll` (a PersistentTreeMap or PersistentTreeSet) is ordered in a way the engine can honour with its fixed unsigned byte ordering: either Clojure's natural ordering (no custom comparator) or `sorted-key/key-comparator`, which *is* that byte ordering and is what `materialize` stamps onto the collections it rebuilds. Any other custom comparator is rejected.
(keypath-cursor cursor keypath)Recursively goes to keypath and returns the write cursor
Recursively goes to keypath and returns the write cursor
(list->LinkedArrayListCursor! cursor coll)Converts a Clojure list or seq-like collection to a XitDB LinkedArrayList cursor. Optimized for sequential access collections rather than random access ones.
Converts a Clojure list or seq-like collection to a XitDB LinkedArrayList cursor. Optimized for sequential access collections rather than random access ones.
(map->WriteHashMapCursor! cursor m)Writes a Clojure map to a XitDB WriteHashMap. Returns the cursor of the created WriteHashMap.
Writes a Clojure map to a XitDB WriteHashMap. Returns the cursor of the created WriteHashMap.
(map-write-cursor whm key)Gets a write cursor for the specified key in a WriteHashMap. Creates the key if it doesn't exist.
Gets a write cursor for the specified key in a WriteHashMap. Creates the key if it doesn't exist.
(primitive-for v)Converts a Clojure primitive value to its corresponding XitDB representation. Handles strings, keywords, integers, booleans, and floats. Throws an IllegalArgumentException for unsupported types.
Converts a Clojure primitive value to its corresponding XitDB representation. Handles strings, keywords, integers, booleans, and floats. Throws an IllegalArgumentException for unsupported types.
(read-bytes-with-format-tag cursor)Reads a BYTES value (as a string) at cursor and converts it to a Clojure type.
Checks the formatTag at cursor to determine the type encoded in the bytes object and
converts the value to the respective Clojure type (eg. keyword, boolean, instant, date).
Supported types are in the global constant fmt-tag-value.
If there is no format tag (or it is unknown), returns the value as a string.
Reads a `BYTES` value (as a string) at `cursor` and converts it to a Clojure type. Checks the `formatTag` at cursor to determine the type encoded in the bytes object and converts the value to the respective Clojure type (eg. keyword, boolean, instant, date). Supported types are in the global constant `fmt-tag-value`. If there is no format tag (or it is unknown), returns the value as a string.
(set->WriteCursor! cursor s)Writes a Clojure set s to a XitDB WriteHashSet.
Returns the cursor of the created WriteHashSet.
Writes a Clojure set `s` to a XitDB WriteHashSet. Returns the cursor of the created WriteHashSet.
(sorted-map->WriteSortedMapCursor! cursor m)Writes a Clojure sorted map m to a XitDB WriteSortedMap.
Keys are encoded with the order-preserving codec; values are written
recursively via v->slot!. Returns the cursor of the created WriteSortedMap.
Writes a Clojure sorted map `m` to a XitDB WriteSortedMap. Keys are encoded with the order-preserving codec; values are written recursively via `v->slot!`. Returns the cursor of the created WriteSortedMap.
(sorted-set->WriteSortedSetCursor! cursor s)Writes a Clojure sorted set s to a XitDB WriteSortedSet.
Members are encoded with the order-preserving codec. Returns the cursor of the
created WriteSortedSet.
Writes a Clojure sorted set `s` to a XitDB WriteSortedSet. Members are encoded with the order-preserving codec. Returns the cursor of the created WriteSortedSet.
(v->slot! cursor v)Converts a value to a XitDB slot. Handles WriteArrayList and WriteHashMap instances directly. Recursively processes Clojure maps and collections. Falls back to primitive conversion for other types.
Converts a value to a XitDB slot. Handles WriteArrayList and WriteHashMap instances directly. Recursively processes Clojure maps and collections. Falls back to primitive conversion for other types.
(xit-tag->keyword tag)Converts a XitDB Tag enum to a corresponding Clojure keyword.
Converts a XitDB Tag enum to a corresponding Clojure keyword.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |